@@ -10,15 +10,15 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <getopt.h>
-#include <misc.h>
-#include <phylo_hmm.h>
-#include <em.h>
-#include <sufficient_stats.h>
-#include <bed.h>
-#include <dgamma.h>
-#include <tree_likelihoods.h>
-#include <maf.h>
-#include "phast_cons.h"
+#include <phast/misc.h>
+#include <phast/phylo_hmm.h>
+#include <phast/em.h>
+#include <phast/sufficient_stats.h>
+#include <phast/bed.h>
+#include <phast/dgamma.h>
+#include <phast/tree_likelihoods.h>
+#include <phast/maf.h>
+#include "phast/cons.h"
 
 
 struct phastCons_struct *phastCons_struct_new(int rphast) {
