@@ -17,23 +17,23 @@ Last updated: 12/14/08
 *****************************************************/
 #include <stdlib.h>
 #include <stdio.h>
-#include <msa.h>
+#include <phast/msa.h>
 #include <getopt.h>
 #include <ctype.h>
-#include <misc.h>
-#include <sufficient_stats.h>
-#include <local_alignment.h>
-#include <maf.h>
-#include <tree_likelihoods.h>
-#include <hmm.h>
-#include <category_map.h>
-#include <gff.h>
-#include <list_of_lists.h>
-#include <matrix.h>
-#include <sufficient_stats.h>
-#include <phylo_fit.h>
-#include <rph_util.h>
-#include <memory_handler.h>
+#include <phast/misc.h>
+#include <phast/sufficient_stats.h>
+#include <phast/local_alignment.h>
+#include <phast/maf.h>
+#include <phast/tree_likelihoods.h>
+#include <phast/hmm.h>
+#include <phast/category_map.h>
+#include <phast/gff.h>
+#include <phast/list_of_lists.h>
+#include <phast/matrix.h>
+#include <phast/sufficient_stats.h>
+#include <phast/phylo_fit.h>
+#include <phast/rph_util.h>
+#include <phast/memory_handler.h>
 
 #include <Rdefines.h>
 #include <R_ext/Random.h>
